@@ -6,7 +6,7 @@ a person from the IMDb database.
 It can fetch data through different media (e.g.: the IMDb web pages,
 a SQL database, etc.)
 
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 __all__ = ['IMDb', 'IMDbError', 'Movie', 'Person', 'Character', 'Company',
            'available_access_systems']
-__version__ = VERSION = '6.2'
+__version__ = VERSION = '6.3'
 
 VERSION_NOTICE = """This version of IMDbPY requires Python 3.
 For a version compatible with Python 2.7, see the imdbpy-legacy branch:
@@ -57,34 +57,34 @@ _aux_logger = logging.getLogger('imdbpy.aux')
 
 
 # URLs of the main pages for movies, persons, characters and queries.
-imdbURL_base = 'http://akas.imdb.com/'
+imdbURL_base = 'http://www.imdb.com/'
 
 # NOTE: the urls below will be removed in a future version.
 #       please use the values in the 'urls' attribute
 #       of the IMDbBase subclass instance.
-# http://akas.imdb.com/title/
+# http://www.imdb.com/title/
 imdbURL_movie_base = '%stitle/' % imdbURL_base
-# http://akas.imdb.com/title/tt%s/
+# http://www.imdb.com/title/tt%s/
 imdbURL_movie_main = imdbURL_movie_base + 'tt%s/'
-# http://akas.imdb.com/name/
+# http://www.imdb.com/name/
 imdbURL_person_base = '%sname/' % imdbURL_base
-# http://akas.imdb.com/name/nm%s/
+# http://www.imdb.com/name/nm%s/
 imdbURL_person_main = imdbURL_person_base + 'nm%s/'
-# http://akas.imdb.com/character/
+# http://www.imdb.com/character/
 imdbURL_character_base = '%scharacter/' % imdbURL_base
-# http://akas.imdb.com/character/ch%s/
+# http://www.imdb.com/character/ch%s/
 imdbURL_character_main = imdbURL_character_base + 'ch%s/'
-# http://akas.imdb.com/company/
+# http://www.imdb.com/company/
 imdbURL_company_base = '%scompany/' % imdbURL_base
-# http://akas.imdb.com/company/co%s/
+# http://www.imdb.com/company/co%s/
 imdbURL_company_main = imdbURL_company_base + 'co%s/'
-# http://akas.imdb.com/keyword/%s/
+# http://www.imdb.com/keyword/%s/
 imdbURL_keyword_main = imdbURL_base + 'keyword/%s/'
-# http://akas.imdb.com/chart/top
+# http://www.imdb.com/chart/top
 imdbURL_top250 = imdbURL_base + 'chart/top'
-# http://akas.imdb.com/chart/bottom
+# http://www.imdb.com/chart/bottom
 imdbURL_bottom100 = imdbURL_base + 'chart/bottom'
-# http://akas.imdb.com/find?%s
+# http://www.imdb.com/find?%s
 imdbURL_find = imdbURL_base + 'find?%s'
 
 # Name of the configuration file.
@@ -194,6 +194,9 @@ def IMDb(accessSystem=None, *arguments, **keywords):
     if accessSystem in ('http', 'web', 'html'):
         from .parser.http import IMDbHTTPAccessSystem
         return IMDbHTTPAccessSystem(*arguments, **keywords)
+    if accessSystem in ('s3', 's3dataset'):
+        from .parser.s3 import IMDbS3AccessSystem
+        return IMDbS3AccessSystem(*arguments, **keywords)
     elif accessSystem in ('sql', 'db', 'database'):
         try:
             from .parser.sql import IMDbSqlAccessSystem
@@ -272,29 +275,29 @@ class IMDbBase:
             imdbURL_base = 'http://%s' % imdbURL_base
         if not imdbURL_base.endswith('/'):
             imdbURL_base = '%s/' % imdbURL_base
-        # http://akas.imdb.com/title/
+        # http://www.imdb.com/title/
         imdbURL_movie_base = '%stitle/' % imdbURL_base
-        # http://akas.imdb.com/title/tt%s/
+        # http://www.imdb.com/title/tt%s/
         imdbURL_movie_main = imdbURL_movie_base + 'tt%s/'
-        # http://akas.imdb.com/name/
+        # http://www.imdb.com/name/
         imdbURL_person_base = '%sname/' % imdbURL_base
-        # http://akas.imdb.com/name/nm%s/
+        # http://www.imdb.com/name/nm%s/
         imdbURL_person_main = imdbURL_person_base + 'nm%s/'
-        # http://akas.imdb.com/character/
+        # http://www.imdb.com/character/
         imdbURL_character_base = '%scharacter/' % imdbURL_base
-        # http://akas.imdb.com/character/ch%s/
+        # http://www.imdb.com/character/ch%s/
         imdbURL_character_main = imdbURL_character_base + 'ch%s/'
-        # http://akas.imdb.com/company/
+        # http://www.imdb.com/company/
         imdbURL_company_base = '%scompany/' % imdbURL_base
-        # http://akas.imdb.com/company/co%s/
+        # http://www.imdb.com/company/co%s/
         imdbURL_company_main = imdbURL_company_base + 'co%s/'
-        # http://akas.imdb.com/keyword/%s/
+        # http://www.imdb.com/keyword/%s/
         imdbURL_keyword_main = imdbURL_base + 'keyword/%s/'
-        # http://akas.imdb.com/chart/top
+        # http://www.imdb.com/chart/top
         imdbURL_top250 = imdbURL_base + 'chart/top'
-        # http://akas.imdb.com/chart/bottom
+        # http://www.imdb.com/chart/bottom
         imdbURL_bottom100 = imdbURL_base + 'chart/bottom'
-        # http://akas.imdb.com/find?%s
+        # http://www.imdb.com/find?%s
         imdbURL_find = imdbURL_base + 'find?%s'
         self.urls = dict(
             movie_base=imdbURL_movie_base,
@@ -591,8 +594,6 @@ class IMDbBase:
             results = int(results)
         except (ValueError, OverflowError):
             results = 100
-        # XXX: I suppose it will be much safer if the user provides
-        #      an unicode string... this is just a guess.
         res = self._get_keyword(keyword, results)
         return [Movie.Movie(movieID=self._get_real_movieID(mi),
                 data=md, modFunct=self._defModFunct,
@@ -763,7 +764,7 @@ class IMDbBase:
         raise NotImplementedError('override this method')
 
     def _searchIMDb(self, kind, ton, title_kind=None):
-        """Search the IMDb akas server for the given title or name."""
+        """Search the IMDb www server for the given title or name."""
         if not ton:
             return None
         ton = ton.strip('"')
