@@ -429,7 +429,7 @@ class IMDbHTTPAccessSystem(IMDbBase):
         return self.smProxy.search_movie_parser.parse(cont, results=results)['data']
 
     def get_movie_main(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'combined')
+        cont = self._retrieve(self.urls['movie_main'] % movieID + 'reference')
         return self.mProxy.movie_parser.parse(cont, mdparse=self._mdparse)
 
     def get_movie_full_credits(self, movieID):
@@ -438,7 +438,9 @@ class IMDbHTTPAccessSystem(IMDbBase):
 
     def get_movie_plot(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'plotsummary')
-        return self.mProxy.plot_parser.parse(cont, getRefs=self._getRefs)
+        ret = self.mProxy.plot_parser.parse(cont, getRefs=self._getRefs)
+        ret['info sets'] = ('plot', 'synopsis')
+        return ret
 
     def get_movie_awards(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'awards')
@@ -482,10 +484,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'ratings')
         return self.mProxy.ratings_parser.parse(cont)
 
-    def get_movie_official_sites(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'officialsites')
-        return self.mProxy.officialsites_parser.parse(cont)
-
     def get_movie_trivia(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'trivia')
         return self.mProxy.trivia_parser.parse(cont, getRefs=self._getRefs)
@@ -518,6 +516,10 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'recommendations')
         return self.mProxy.rec_parser.parse(cont)
 
+    def get_movie_reviews(self, movieID):
+        cont = self._retrieve(self.urls['movie_main'] % movieID + 'reviews?count=9999999&start=0')
+        return self.mProxy.reviews_parser.parse(cont)
+
     def get_movie_critic_reviews(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'criticreviews')
         return self.mProxy.criticrev_parser.parse(cont)
@@ -526,21 +528,47 @@ class IMDbHTTPAccessSystem(IMDbBase):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'externalreviews')
         return self.mProxy.externalrev_parser.parse(cont)
 
+    def get_movie_external_sites(self, movieID):
+        cont = self._retrieve(self.urls['movie_main'] % movieID + 'externalsites')
+        ret = self.mProxy.externalsites_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
+
+    def get_movie_official_sites(self, movieID):
+        cont = self._retrieve(self.urls['movie_main'] % movieID + 'officialsites')
+        ret = self.mProxy.officialsites_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
+
     def get_movie_misc_sites(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'miscsites')
-        return self.mProxy.misclinks_parser.parse(cont)
+        ret = self.mProxy.misclinks_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
 
     def get_movie_sound_clips(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'soundsites')
-        return self.mProxy.soundclips_parser.parse(cont)
+        ret = self.mProxy.soundclips_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
 
     def get_movie_video_clips(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'videosites')
-        return self.mProxy.videoclips_parser.parse(cont)
+        ret = self.mProxy.videoclips_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
 
     def get_movie_photo_sites(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'photosites')
-        return self.mProxy.photosites_parser.parse(cont)
+        ret = self.mProxy.photosites_parser.parse(cont)
+        ret['info sets'] = ('external sites', 'misc sites', 'sound clips',
+                            'video sites', 'photo sites', 'official sites')
+        return ret
 
     def get_movie_news(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'news')
@@ -587,16 +615,6 @@ class IMDbHTTPAccessSystem(IMDbBase):
         data_d['data']['number of episodes'] = nr_eps
         return data_d
 
-    def get_movie_episodes_rating(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'epdate', _noCookies=True)
-        data_d = self.mProxy.eprating_parser.parse(cont)
-        # set movie['episode of'].movieID for every episode.
-        if 'episodes rating' in data_d.get('data', {}):
-            for item in data_d['data']['episodes rating']:
-                episode = item['episode']
-                episode['episode of'].movieID = movieID
-        return data_d
-
     def get_movie_faqs(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'faq')
         return self.mProxy.movie_faqs_parser.parse(cont, getRefs=self._getRefs)
@@ -608,8 +626,7 @@ class IMDbHTTPAccessSystem(IMDbBase):
     get_movie_tv_schedule = get_movie_airing
 
     def get_movie_synopsis(self, movieID):
-        cont = self._retrieve(self.urls['movie_main'] % movieID + 'synopsis')
-        return self.mProxy.synopsis_parser.parse(cont)
+        return self.get_movie_plot(movieID)
 
     def get_movie_parents_guide(self, movieID):
         cont = self._retrieve(self.urls['movie_main'] % movieID + 'parentalguide')
@@ -710,7 +727,7 @@ class IMDbHTTPAccessSystem(IMDbBase):
     def _search_keyword(self, keyword, results):
         # XXX: the IMDb web server seems to have some serious problem with
         #      non-ascii keyword.
-        #      E.g.: http://akas.imdb.com/keyword/fianc%E9/
+        #      E.g.: http://www.imdb.com/keyword/fianc%E9/
         #      will return a 500 Internal Server Error: Redirect Recursion.
         try:
             cont = self._get_search_content('kw', keyword, results)
