@@ -2,14 +2,14 @@
 parser.http.personParser module (imdb package).
 
 This module provides the classes (and the instances), used to parse
-the IMDb pages on the akas.imdb.com server about a person.
+the IMDb pages on the www.imdb.com server about a person.
 E.g., for "Mel Gibson" the referred pages would be:
-    categorized:    http://akas.imdb.com/name/nm0000154/maindetails
-    biography:      http://akas.imdb.com/name/nm0000154/bio
+    categorized:    http://www.imdb.com/name/nm0000154/maindetails
+    biography:      http://www.imdb.com/name/nm0000154/bio
     ...and so on...
 
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
-               2008 H. Turgut Uyar <uyar@tekir.org>
+Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+          2008-2017 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -40,25 +40,14 @@ from .movieParser import (
 from .utils import Attribute, DOMParserBase, Extractor, analyze_imdbid, build_movie
 
 
+_re_spaces = re.compile(r'\s+')
 _reRoles = re.compile(r'(<li>.*? \.\.\.\. )(.*?)(</li>|<br>)', re.I | re.M | re.S)
 
 
-def build_date(date):
-    day = date.get('day')
-    year = date.get('year')
-    if day and year:
-        return "%s %s" % (day, year)
-    if day:
-        return day
-    if year:
-        return year
-    return ""
-
-
 class DOMHTMLMaindetailsParser(DOMParserBase):
     """Parser for the "categorized" (maindetails) page of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -244,7 +233,7 @@ class DOMHTMLMaindetailsParser(DOMParserBase):
 class DOMHTMLBioParser(DOMParserBase):
     """Parser for the "biography" page of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -256,11 +245,7 @@ class DOMHTMLBioParser(DOMParserBase):
     _birth_attrs = [
         Attribute(
             key='birth date',
-            path={
-                'day': "./a[starts-with(@href, '/search/name?birth_monthday=')]/text()",
-                'year': "./a[starts-with(@href, '/search/name?birth_year=')]/text()"
-            },
-            postprocess=build_date
+            path="./time[@itemprop='birthDate']/@datetime"
         ),
 
         Attribute(
@@ -272,49 +257,51 @@ class DOMHTMLBioParser(DOMParserBase):
     _death_attrs = [
         Attribute(
             key='death date',
-            path={
-                'day': "./a[starts-with(@href, '/search/name?death_monthday=')]/text()",
-                'year': "./a[starts-with(@href, '/search/name?death_date=')]/text()"
-            },
-            postprocess=build_date
+            path="./time[@itemprop='deathDate']/@datetime"
+        ),
+
+        Attribute(
+            key='death cause',
+            path="./text()",
+            # TODO: check if this slicing is always correct
+            postprocess=lambda x: ''.join(x).strip()[2:].lstrip()
         ),
 
         Attribute(
             key='death notes',
-            path="./text()",
-            # TODO: check if this slicing is always correct
-            postprocess=lambda x: ''.join(x).strip()[2:]
+            path="..//text()",
+            postprocess=lambda x: _re_spaces.sub(' ', (x or '').strip().split('\n')[-1])
         )
     ]
 
     extractors = [
         Extractor(
             label='headshot',
-            path="//a[@name='headshot']",
+            path="//img[@class='poster']",
             attrs=Attribute(
                 key='headshot',
-                path="./img/@src"
+                path="./@src"
             )
         ),
 
         Extractor(
             label='birth info',
             path="//table[@id='overviewTable']"
-                 "//td[text()='Date of Birth']/following-sibling::td[1]",
+                 "//td[text()='Born']/following-sibling::td[1]",
             attrs=_birth_attrs
         ),
 
         Extractor(
             label='death info',
             path="//table[@id='overviewTable']"
-                 "//td[text()='Date of Death']/following-sibling::td[1]",
+                 "//td[text()='Died']/following-sibling::td[1]",
             attrs=_death_attrs
         ),
 
         Extractor(
             label='nick names',
             path="//table[@id='overviewTable']"
-                 "//td[text()='Nickenames']/following-sibling::td[1]",
+                 "//td[starts-with(text(), 'Nickname')]/following-sibling::td[1]",
             attrs=Attribute(
                 key='nick names',
                 path="./text()",
@@ -365,7 +352,7 @@ class DOMHTMLBioParser(DOMParserBase):
 
         Extractor(
             label='spouse',
-            path="//div[h5='Spouse']/table/tr",
+            path="//a[@name='spouse']/following::table[1]//tr",
             attrs=Attribute(
                 key='spouse',
                 multi=True,
@@ -375,13 +362,14 @@ class DOMHTMLBioParser(DOMParserBase):
                 },
                 postprocess=lambda x: ("%s::%s" % (
                     x.get('name').strip(),
-                    (x.get('info') or '').strip())).strip(':')
+                    (_re_spaces.sub(' ', x.get('info') or '')).strip())).strip(':')
             )
         ),
 
         Extractor(
             label='trade mark',
-            path="//div[h5='Trade Mark']/p",
+            path="//div[@class='_imdbpyh4']/h4[starts-with(text(), 'Trade Mark')]" +
+                    "/.././div[contains(@class, 'soda')]",
             attrs=Attribute(
                 key='trade mark',
                 multi=True,
@@ -392,7 +380,8 @@ class DOMHTMLBioParser(DOMParserBase):
 
         Extractor(
             label='trivia',
-            path="//div[h5='Trivia']/p",
+            path="//div[@class='_imdbpyh4']/h4[starts-with(text(), 'Trivia')]" +
+                    "/.././div[contains(@class, 'soda')]",
             attrs=Attribute(
                 key='trivia',
                 multi=True,
@@ -403,7 +392,8 @@ class DOMHTMLBioParser(DOMParserBase):
 
         Extractor(
             label='quotes',
-            path="//div[h5='Personal Quotes']/p",
+            path="//div[@class='_imdbpyh4']/h4[starts-with(text(), 'Personal Quotes')]" +
+                    "/.././div[contains(@class, 'soda')]",
             attrs=Attribute(
                 key='quotes',
                 multi=True,
@@ -414,41 +404,31 @@ class DOMHTMLBioParser(DOMParserBase):
 
         Extractor(
             label='salary',
-            path="//div[h5='Salary']/table/tr",
+            path="//a[@name='salary']/following::table[1]//tr",
             attrs=Attribute(
                 key='salary history',
                 multi=True,
                 path={
                     'title': "./td[1]//text()",
-                    'info': "./td[2]/text()",
+                    'info': "./td[2]//text()",
                 },
                 postprocess=lambda x: "%s::%s" % (
                     x.get('title').strip(),
-                    x.get('info').strip())
-            )
-        ),
-
-        Extractor(
-            label='where now',
-            path="//div[h5='Where Are They Now']/p",
-            attrs=Attribute(
-                key='where now',
-                multi=True,
-                path=".//text()",
-                postprocess=lambda x: x.strip()
+                    _re_spaces.sub(' ', (x.get('info') or '')).strip())
             )
         )
     ]
 
     preprocessors = [
         (re.compile('(<h5>)', re.I), r'</div><div class="_imdbpy">\1'),
+        (re.compile('(<h4)', re.I), r'</div><div class="_imdbpyh4">\1'),
         (re.compile('(</table>\n</div>\s+)</div>', re.I + re.DOTALL), r'\1'),
         (re.compile('(<div id="tn15bot">)'), r'</div>\1'),
         (re.compile('\.<br><br>([^\s])', re.I), r'. \1')
     ]
 
     def postprocess_data(self, data):
-        for what in 'birth date', 'death date':
+        for what in 'birth date', 'death date', 'death cause':
             if what in data and not data[what]:
                 del data[what]
         return data
@@ -457,7 +437,7 @@ class DOMHTMLBioParser(DOMParserBase):
 class DOMHTMLResumeParser(DOMParserBase):
     """Parser for the "resume" page of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -584,9 +564,9 @@ class DOMHTMLResumeParser(DOMParserBase):
 
 
 class DOMHTMLOtherWorksParser(DOMParserBase):
-    """Parser for the "other works" and "agent" pages of a given person.
+    """Parser for the "other works" page of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -594,28 +574,20 @@ class DOMHTMLOtherWorksParser(DOMParserBase):
         result = owparser.parse(otherworks_html_string)
     """
     _defGetRefs = True
-    kind = 'other works'
 
-    # XXX: looks like the 'agent' page is no more public.
     extractors = [
         Extractor(
             label='other works',
-            path="//h5[text()='Other works']/following-sibling::div[1]",
+            path="//li[@class='ipl-zebra-list__item']",
             attrs=Attribute(
-                key='self.kind',
+                key='other works',
                 path=".//text()",
-                postprocess=lambda x: x.strip().split('\n\n')
+                multi=True,
+                postprocess=lambda x: x.strip()
             )
         )
     ]
 
-    preprocessors = [
-        (re.compile('(<h5>[^<]+</h5>)', re.I), r'</div>\1<div class="_imdbpy">'),
-        (re.compile('(</table>\n</div>\s+)</div>', re.I), r'\1'),
-        (re.compile('(<div id="tn15bot">)'), r'</div>\1'),
-        (re.compile('<br/><br/>', re.I), r'\n\n')
-    ]
-
 
 def _build_episode(link, title, minfo, role, roleA, roleAID):
     """Build an Movie object for a given episode of a series."""
@@ -661,7 +633,7 @@ def _build_episode(link, title, minfo, role, roleA, roleAID):
 class DOMHTMLSeriesParser(DOMParserBase):
     """Parser for the "by TV series" page of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -722,7 +694,7 @@ class DOMHTMLSeriesParser(DOMParserBase):
 class DOMHTMLPersonGenresParser(DOMParserBase):
     """Parser for the "by genre" and "by keywords" pages of a given person.
     The page should be provided as a string, as taken from
-    the akas.imdb.com server.  The final result will be a
+    the www.imdb.com server.  The final result will be a
     dictionary, with a key for every relevant section.
 
     Example:
@@ -765,7 +737,6 @@ _OBJECTS = {
     'bio_parser': ((DOMHTMLBioParser,), None),
     'resume_parser': ((DOMHTMLResumeParser,), None),
     'otherworks_parser': ((DOMHTMLOtherWorksParser,), None),
-    # 'agent_parser': ((DOMHTMLOtherWorksParser,), {'kind': 'agent'}),
     'person_officialsites_parser': ((DOMHTMLOfficialsitesParser,), None),
     'person_awards_parser': ((DOMHTMLAwardsParser,), {'subject': 'name'}),
     'publicity_parser': ((DOMHTMLTechParser,), {'kind': 'publicity'}),
